# OPS07-BP04: Use playbooks to investigate issues

## Description

Playbooks cho troubleshooting và incident response.

## Implementation Guidance

- Playbooks for known failure modes
- Decision trees for diagnosis
- Links to relevant dashboards
- Escalation guidance
- Post-incident playbook updates

## Risk Level

Medium - Without playbooks, incident response is slower.
